spoon.ber.Tag

Package spoon :: Package ber :: Class Tag |
[hide private]
[frames] | no frames]

# Class Tag

source code

    object --+
             |
            Tag

Representation of the header of an ASN.1 object. This includes the class (universal, application, context, or private), the type tag (any integer), and size.

Instance Methods | [hide private]
`` | __cmp__(self, other)
`` | __hash__(self) hash(x)
`` | __init__(self, tag_class=0, tag=0, size=None, container=False, _bytes_read=0) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __len__(self)
`` | __repr__(self) repr(x)
`` | is_terminator(self) Return `True` if this tag is the special type used to terminate indefinite-length sequences (type 0, length 0).
`` | write(self, fd)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Static Methods | [hide private]
`` | from_stream(fd)
`` | from_tag(t, size=None)
`` | make_terminator() Return a tag that can be used to terminate indefinite-length sequences.

Properties | [hide private]
`` | container
`` | size
`` | tag
`` | tag_class
Inherited from `object`: `__class__`

Method Details | [hide private]

### __cmp__(self, other) (Comparison operator) | source code
None

### __hash__(self) (Hashing function) | source code
hash(x) Overrides: object.__hash__ (inherited documentation)

### __init__(self, tag_class=0, tag=0, size=None, container=False, _bytes_read=0) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __len__(self) (Length operator) | source code
None

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### from_stream(fd) Static Method |
None

### from_tag(t, size=None) Static Method |
None

### is_terminator(self) | source code
Return `True` if this tag is the special type used to terminate indefinite-length sequences (type 0, length 0).

### make_terminator() Static Method |
Return a tag that can be used to terminate indefinite-length sequences.

### write(self, fd) | source code
None

Property Details | [hide private]

    ### container None Get Method: unreachable(self) Set Method:
        None
    Delete Method:
        None

    ### size None Get Method: unreachable(self) Set Method:
        None
    Delete Method:
        None

    ### tag None Get Method: unreachable(self) Set Method:
        None
    Delete Method:
        None

    ### tag_class None Get Method: unreachable(self) Set Method:
        None
    Delete Method:
        None